==> primevue-3.46.0.tgz: package/icons/exclamationtriangle/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.exclamationtriangle = (function (BaseIcon, utils, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
      name: 'ExclamationTriangleIcon',
      "extends": BaseIcon__default["default"],
      computed: {
        pathId: function pathId() {
          return "pv_icon_clip_".concat(utils.UniqueComponentId());
        }
      }
    };

    var _hoisted_1 = ["clip-path"];
    var _hoisted_2 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M13.4018 13.1893H0.598161C0.49329 13.189 0.390283 13.1615 0.299143 13.1097C0.208003 13.0578 0.131826 12.9832 0.0780112 12.8932C0.0268539 12.8015 0 12.6982 0 12.5931C0 12.4881 0.0268539 12.3848 0.0780112 12.293L6.47985 1.08982C6.53679 1.00399 6.61408 0.933574 6.70484 0.884867C6.7956 0.836159 6.897 0.810669 7 0.810669C7.103 0.810669 7.2044 0.836159 7.29516 0.884867C7.38592 0.933574 7.46321 1.00399 7.52015 1.08982L13.922 12.293C13.9731 12.3848 14 12.4881 14 12.5931C14 12.6982 13.9731 12.8015 13.922 12.8932C13.8682 12.9832 13.792 13.0578 13.7009 13.1097C13.6097 13.1615 13.5067 13.189 13.4018 13.1893ZM1.63046 11.989H12.3695L7 2.59425L1.63046 11.989Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_3 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M6.99996 8.78801C6.84143 8.78594 6.68997 8.72204 6.57787 8.60993C6.46576 8.49782 6.40186 8.34637 6.39979 8.18784V5.38703C6.39979 5.22786 6.46302 5.0752 6.57557 4.96265C6.68813 4.85009 6.84078 4.78686 6.99996 4.78686C7.15914 4.78686 7.31179 4.85009 7.42435 4.96265C7.5369 5.0752 7.60013 5.22786 7.60013 5.38703V8.18784C7.59806 8.34637 7.53416 8.49782 7.42205 8.60993C7.30995 8.72204 7.15849 8.78594 6.99996 8.78801Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_4 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M6.99996 11.1887C6.84143 11.1866 6.68997 11.1227 6.57787 11.0106C6.46576 10.8985 6.40186 10.7471 6.39979 10.5885V10.1884C6.39979 10.0292 6.46302 9.87658 6.57557 9.76403C6.68813 9.65147 6.84078 9.58824 6.99996 9.58824C7.15914 9.58824 7.31179 9.65147 7.42435 9.76403C7.5369 9.87658 7.60013 10.0292 7.60013 10.1884V10.5885C7.59806 10.7471 7.53416 10.8985 7.42205 11.0106C7.30995 11.1227 7.15849 11.1866 6.99996 11.1887Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_5 = [_hoisted_2, _hoisted_3, _hoisted_4];
    var _hoisted_6 = ["id"];
    var _hoisted_7 = /*#__PURE__*/vue.createElementVNode("rect", {
      width: "14",
      height: "14",
      fill: "white"
    }, null, -1);
    var _hoisted_8 = [_hoisted_7];
    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), [vue.createElementVNode("g", {
        "clip-path": "url(#".concat($options.pathId, ")")
      }, _hoisted_5, 8, _hoisted_1), vue.createElementVNode("defs", null, [vue.createElementVNode("clipPath", {
        id: "".concat($options.pathId)
      }, _hoisted_8, 8, _hoisted_6)])], 16);
    }

    script.render = render;

    return script;

})(primevue.baseicon, primevue.utils, Vue);

==> primevue-3.47.0.tgz: package/icons/exclamationtriangle/index.js <==
this.primevue = this.primevue || {};
this.primevue.icons = this.primevue.icons || {};
this.primevue.icons.exclamationtriangle = (function (BaseIcon, vue) {
    'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var BaseIcon__default = /*#__PURE__*/_interopDefaultLegacy(BaseIcon);

    var script = {
      name: 'ExclamationTriangleIcon',
      "extends": BaseIcon__default["default"]
    };

    var _hoisted_1 = ["clip-path"];
    var _hoisted_2 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M13.4018 13.1893H0.598161C0.49329 13.189 0.390283 13.1615 0.299143 13.1097C0.208003 13.0578 0.131826 12.9832 0.0780112 12.8932C0.0268539 12.8015 0 12.6982 0 12.5931C0 12.4881 0.0268539 12.3848 0.0780112 12.293L6.47985 1.08982C6.53679 1.00399 6.61408 0.933574 6.70484 0.884867C6.7956 0.836159 6.897 0.810669 7 0.810669C7.103 0.810669 7.2044 0.836159 7.29516 0.884867C7.38592 0.933574 7.46321 1.00399 7.52015 1.08982L13.922 12.293C13.9731 12.3848 14 12.4881 14 12.5931C14 12.6982 13.9731 12.8015 13.922 12.8932C13.8682 12.9832 13.792 13.0578 13.7009 13.1097C13.6097 13.1615 13.5067 13.189 13.4018 13.1893ZM1.63046 11.989H12.3695L7 2.59425L1.63046 11.989Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_3 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M6.99996 8.78801C6.84143 8.78594 6.68997 8.72204 6.57787 8.60993C6.46576 8.49782 6.40186 8.34637 6.39979 8.18784V5.38703C6.39979 5.22786 6.46302 5.0752 6.57557 4.96265C6.68813 4.85009 6.84078 4.78686 6.99996 4.78686C7.15914 4.78686 7.31179 4.85009 7.42435 4.96265C7.5369 5.0752 7.60013 5.22786 7.60013 5.38703V8.18784C7.59806 8.34637 7.53416 8.49782 7.42205 8.60993C7.30995 8.72204 7.15849 8.78594 6.99996 8.78801Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_4 = /*#__PURE__*/vue.createElementVNode("path", {
      d: "M6.99996 11.1887C6.84143 11.1866 6.68997 11.1227 6.57787 11.0106C6.46576 10.8985 6.40186 10.7471 6.39979 10.5885V10.1884C6.39979 10.0292 6.46302 9.87658 6.57557 9.76403C6.68813 9.65147 6.84078 9.58824 6.99996 9.58824C7.15914 9.58824 7.31179 9.65147 7.42435 9.76403C7.5369 9.87658 7.60013 10.0292 7.60013 10.1884V10.5885C7.59806 10.7471 7.53416 10.8985 7.42205 11.0106C7.30995 11.1227 7.15849 11.1866 6.99996 11.1887Z",
      fill: "currentColor"
    }, null, -1);
    var _hoisted_5 = [_hoisted_2, _hoisted_3, _hoisted_4];
    var _hoisted_6 = ["id"];
    var _hoisted_7 = /*#__PURE__*/vue.createElementVNode("rect", {
      width: "14",
      height: "14",
      fill: "white"
    }, null, -1);
    var _hoisted_8 = [_hoisted_7];
    function render(_ctx, _cache, $props, $setup, $data, $options) {
      return vue.openBlock(), vue.createElementBlock("svg", vue.mergeProps({
        width: "14",
        height: "14",
        viewBox: "0 0 14 14",
        fill: "none",
        xmlns: "http://www.w3.org/2000/svg"
      }, _ctx.pti()), [vue.createElementVNode("g", {
        "clip-path": "url(#".concat(_ctx.pathId, ")")
      }, _hoisted_5, 8, _hoisted_1), vue.createElementVNode("defs", null, [vue.createElementVNode("clipPath", {
        id: "".concat(_ctx.pathId)
      }, _hoisted_8, 8, _hoisted_6)])], 16);
    }

    script.render = render;

    return script;

})(primevue.baseicon, Vue);
